<?php
/**
 * @version  $Id$
 * @author  JoomlaUX!
 * @package  Joomla.Site
 * @subpackage mod_jux_carousel
 * @copyright Copyright (C) 2012 by JoomlaUX. All rights reserved.
 * @license  http://www.gnu.org/licenses/gpl.html
 */
defined('JPATH_BASE') or die;

jimport('joomla.html.html');
jimport('joomla.form.formfield');

/**
 * Create Accordion Options.
 * Example xml:
 * <field
 * 	type="JUXAccordionOptions"
 * 	pane_type="end"					<!-- pane_type is 'child' or 'end', default is 'end'. If it's end accordion, there's onload scipt add to the accordion -->
 *	accordion_id=""					<!-- in case there's more than one Accordion you need to specify this id for them to work -->
 * 	label="MOD_JUX_LABEL"
 * 	description="MOD_JUX_DESC">
 * </field>
 */
class JFormFieldJUXAccordionOptions extends JFormField {

	protected $type = 'JUXAccordionOptions';

	/**
	 * Method to get the field input markup.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   11.1
	 */
	protected function getLabel() {
		
		// add script
		if (!defined('JUX_MODULE_OPTIONS_ASSETS')) {
			define('JUX_MODULE_OPTIONS_ASSETS', 1);
			$uri = str_replace('\\', "/", str_replace(JPATH_SITE, JURI::base(), dirname(__FILE__)));
			$uri = str_replace("/administrator/", "", $uri);
			JHTML::stylesheet($uri . '/assets/css/juxoptions.css');
			JHTML::script($uri . '/assets/js/juxoptions.js');
		}
		
		$_accordion_id	= 'jux_accordion';
		$_toggler_class	= 'jux_toggler';
		$_element_class	= 'jux_element';

		$accordion_id	= (string) $this->element['accordion_id'];
		if($accordion_id) {
			$_accordion_id	= $_accordion_id.'_'.$accordion_id;
			$_toggler_class	= $_toggler_class.'_'.$accordion_id;
			$_element_class	= $_element_class.'_'.$accordion_id;
		}
		
		$_pane_id		= time()+rand();
		$_pane_type		= $this->element['pane_type'] ? (string) $this->element['pane_type'] : 'child';

		// Declare variable for Accordion class
		if(!defined('JUX_MODULE_OPTIONS_ACCORDION_'.$_accordion_id)) {
			define('JUX_MODULE_OPTIONS_ACCORDION_'.$_accordion_id, 1);
			?>
				<script type="text/javascript">
					var jux_accordion_<?php echo $_accordion_id; ?> = new JUX_Accordion_Options('<?php echo $_toggler_class; ?>', '<?php echo $_element_class; ?>');
				</script>
			<?php
		}

		$html	= '<div id="'.$_pane_id.'" class="clr"></div>';
		if($_pane_type == 'child') {
			$_title = (string) $this->element['label'];
			if ($_title) {
				$_title = html_entity_decode(JText::_($_title));
			}

			$_description = $this->description;
			if ($_description) {
				$_description = html_entity_decode(JText::_($_description));
				$_description = '<span class="icon-help editlinktip hasTip" title="' . htmlentities($_description) . '"></span>';
			}

			$html	.= '
				<h4 class="jux_option_toggler '.$_toggler_class.'">
					<span class="block-setting" >' . $_title . '</span> 
					'.$_description.'
					<span class="control-icon"></span>
				</h4>';
		}

		// Add new pane to the Accordion
		?>
		<script type="text/javascript">
			window.addEvent('domready', function() {
				jux_accordion_<?php echo $_accordion_id; ?>.addPane('<?php echo $_pane_id; ?>');
			});
		</script>
		<?php

		// On load Script for main accordion
		if($_pane_type == 'end') {
			?>
			<script type="text/javascript">
				window.addEvent('domready', function() {
					jux_accordion_<?php echo $_accordion_id; ?>.start();
				});
			</script>
			<?php
		}

		return $html;
	}

	/**
	 * Override getLabel function for hiding Label when don't need.
	 * 
	 * @return string	Label if label element is set, blank otherwise
	 */
	protected function getInput() {
		return '';
	}

}